@@ -1,30 +1,27 @@
-/* 
+/*
  * i-scream central monitoring system
  * http://www.i-scream.org
- * Copyright (C) 2000-2003 i-scream
+ * Copyright (C) 2000-2004 i-scream
  * 
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  * 
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+ * 02111-1307 USA
+ *
+ * $Id: statgrab.h,v 1.23 2004/01/19 16:49:21 tdb Exp $
  */
 
 #include <sys/types.h>
-#ifdef NETBSD
-#include <limits.h>
-#endif
-#ifdef CYGWIN
-#include <sys/unistd.h>
-#endif
 
 typedef struct{
         long long user;
@@ -60,19 +57,6 @@ typedef struct{
 	double min15;
 }load_stat_t;
 
-#ifdef SOLARIS
-#define MAX_LOGIN_NAME_SIZE 8
-#endif
-#if defined(LINUX) || defined(FREEBSD)
-#define MAX_LOGIN_NAME_SIZE UT_NAMESIZE
-#endif
-#ifdef NETBSD
-#define MAX_LOGIN_NAME_SIZE _POSIX_LOGIN_NAME_MAX
-#endif
-#if defined(CYGWIN)
-#define MAX_LOGIN_NAME_SIZE _SC_LOGIN_NAME_MAX
-#endif
-
 typedef struct{
 	char *name_list;
 	int num_entries;
