@@ -1,21 +1,24 @@
-/* 
+/*
  * i-scream central monitoring system
  * http://www.i-scream.org
- * Copyright (C) 2000-2003 i-scream
+ * Copyright (C) 2000-2004 i-scream
  * 
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  * 
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+ * 02111-1307 USA
+ *
+ * $Id: user_stats.c,v 1.17 2004/01/21 14:44:22 ats Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,7 +32,26 @@
 #ifdef ALLBSD
 #include <sys/types.h>
 #endif
+#ifdef NETBSD
+#include <limits.h>
+#endif
 #include <utmp.h>
+#ifdef CYGWIN
+#include <sys/unistd.h>
+#endif
+
+#ifdef SOLARIS
+#define MAX_LOGIN_NAME_SIZE 8
+#endif
+#if defined(LINUX) || defined(FREEBSD)
+#define MAX_LOGIN_NAME_SIZE UT_NAMESIZE
+#endif
+#ifdef NETBSD
+#define MAX_LOGIN_NAME_SIZE _POSIX_LOGIN_NAME_MAX
+#endif
+#if defined(CYGWIN)
+#define MAX_LOGIN_NAME_SIZE _SC_LOGIN_NAME_MAX
+#endif
 
 #define START_VAL (5*(1+MAX_LOGIN_NAME_SIZE))
 
